#!/bin/bash
# This script is used to clean and categorize the BGA abstracts from 2009-2019
# using the script abstract_cleaner.py for Becker et al. (2021).

script=abstract_cleaner.py

# 2019
python3 ${script} \
	--pathin "2019_Article_BehaviorGeneticsAssociation49t.txt" \
	--pathout "cleaned_bga2019.csv" \
	--firstpage 488 \
	--lastpage 557 \
	--bga_string 'Behav Genet (2019) 49:4877557' \
	--twin_registries 'Michigan State University Twin Registry' 'Osaka University Center for Twin Research' 'Boston University Twin Project'


# 2018
python3 ${script} \
	--pathin "2018_Article_BehaviorGeneticsAssociation48t.txt" \
	--pathout "cleaned_bga2018.csv" \
	--firstpage 455 \
	--lastpage 526 \
	--bga_string 'Behav Genet (2018) 48:4547526' \
	--twin_registries 'Michigan State University Twin Registry' 'Osaka University Center for Twin Research' 'Boston University Twin Project'


# 2017
python3 ${script} \
	--pathin "2017_Article_BehaviorGeneticsAssociation47t.txt" \
	--pathout "cleaned_bga2017.csv" \
	--firstpage 643 \
	--lastpage 719 \
	--bga_string 'Behav Genet (2017) 47:6427719' \
	--twin_registries 'Michigan State University Twin Registry' 'Osaka University Center for Twin Research' 'Boston University Twin Project' \
		'Center for Twin Research at Osaka University' 'The Norwegian Institute of Public Health Twin Panel' 'Norwegian Institute of Health Twin Panel' \
		'Norwegian Institute of Public Health Twin Panel'


# 2016
python3 ${script} \
	--pathin "2016_Article_BehaviorGeneticsAssociation46t.txt" \
	--pathout "cleaned_bga2016.csv" \
	--firstpage 773 \
	--lastpage 816 \
	--bga_string 'Behav Genet (2016)' \
	--twin_registries 'University Twin Registry' 'Osaka University Center for Twin Research' 'Boston University Twin Project' \
		'Center for Twin Research at Osaka University' 'The Norwegian Institute of Public Health Twin Panel' 'Norwegian Institute of Health Twin Panel' \
		'Norwegian Institute of Public Health Twin Panel' 'National Institute on Aging grants' 'National Institute of Health (' \
		'GSA, Abo Akademi University in Finland' 'MTR, University of Murcia in Spain' 'from the National Institute' 'National Institute of Diabetes and Digestive and Kidney Diseases (' \
		'National Institutes of Health [' 'American Institutes for Research investment funds' 'Population Research Center at the University of Texas at Austin' \
		'National Institutes of Health (' 'The Murray Research Archive at Harvard University' 'University of Texas Press' 'National Institute of Aging (' \
		'National Institute on Mental Health MH66206' 'National Institute on Alcohol Abuse and Alcoholism AA023133' 'Brain Behavior Laboratory of the University of Pennsylvania' \
		'University of Southern California (USC) Risk Factors for Antisocial Behavior (RFAB) twin study' 'National Institute of Mental Health (' \
		'National Institute of Child Health and Human Development (' 'University of Washington Twin Registry' 'Twin Study at the QIMR Berghofer Medical Research Institute' \
		'National Institutes of Health AG' 'Florida Department of Education' 'Twin Study at the University of Colorado' \
		'Sibling Interaction and Behavior Study (SIBS) at the University of Minnesota' 'Twin Study (LTS) at the University of Colorado' \
		'University of Southern California (USC) Twin Project' 'Washington University based Epigenomics Roadmap Visualization Hub' \
		'College Drinking Sample' 'The Netherlands Twin Register at the VU University' 'University of Vermont, Research Center for Children, Youth, and Families' \
		'University of Southern California Twin Study' 'Southern California Twin Register at the University of Southern California' \
		'National Institutes of Health Grants' 'QIMR Berghofer Medical Research Institute (QIMR) cohort' 'Center for Twin Research, Osaka University'


# 2015
python3 ${script} \
	--pathin "2015_Article_BehaviorGeneticsAssociation45t.txt" \
	--pathout "cleaned_bga2015.csv" \
	--firstpage 641 \
	--lastpage 694 \
	--bga_string 'Behav Genet (2015) 45:640494' \
	--twin_registries 'Michigan State University Twin Registry' 'Osaka University Center for Twin Research' 'Boston University Twin Project' \
		'Center for Twin Research at Osaka University' 'The Norwegian Institute of Public Health Twin Panel' 'Norwegian Institute of Health Twin Panel' \
		'Norwegian Institute of Public Health Twin Panel' 'National Institute on Aging grants' 'National Institute of Health (' \
		'GSA, Abo Akademi University in Finland' 'MTR, University of Murcia in Spain' 'from the National Institute' 'National Institute of Diabetes and Digestive and Kidney Diseases (' \
		'National Institutes of Health [' 'American Institutes for Research investment funds' 'Population Research Center at the University of Texas at Austin' \
		'National Institutes of Health (' 'The Murray Research Archive at Harvard University' 'University of Texas Press' 'National Institute of Aging (' \
		'National Institute on Mental Health MH66206' 'National Institute on Alcohol Abuse and Alcoholism AA023133' 'Brain Behavior Laboratory of the University of Pennsylvania' \
		'University of Southern California (USC) Risk Factors for Antisocial Behavior (RFAB) twin study' 'National Institute of Mental Health (' \
		'National Institute of Child Health and Human Development ('


# 2014
python3 ${script} \
	--pathin "2014_Article_BehaviorGeneticsAssociation44t.txt" \
	--pathout "cleaned_bga2014.csv" \
	--firstpage 647 \
	--lastpage 690 \
	--bga_string 'Behav Genet (2014) 44:646490' \
	--twin_registries 'Michigan State University Twin Registry' 'Osaka University Center for Twin Research' 'Boston University Twin Project' \
		'Center for Twin Research at Osaka University' 'The Norwegian Institute of Public Health Twin Panel' 'Norwegian Institute of Health Twin Panel' \
		'Norwegian Institute of Public Health Twin Panel' 'National Institute on Aging grants' 'National Institute of Health (' \
		'GSA, Abo Akademi University in Finland' 'MTR, University of Murcia in Spain' 'from the National Institute' 'National Institute of Diabetes and Digestive and Kidney Diseases (' \
		'National Institutes of Health [' 'American Institutes for Research investment funds' 'Population Research Center at the University of Texas at Austin' \
		'National Institutes of Health (' 'The Murray Research Archive at Harvard University' 'University of Texas Press' 'National Institute of Aging (' \
		'National Institute on Mental Health MH66206' 'National Institute on Alcohol Abuse and Alcoholism AA023133' 'Brain Behavior Laboratory of the University of Pennsylvania' \
		'University of Southern California (USC) Risk Factors for Antisocial Behavior (RFAB) twin study' 'National Institute of Mental Health (' \
		'National Institute of Child Health and Human Development (' 'University of Washington Twin Registry' 'Twin Study at the QIMR Berghofer Medical Research Institute' \
		'National Institutes of Health AG' 'Florida Department of Education'


# 2013
python3 ${script} \
	--pathin "2013_Article_BehaviorGeneticsAssociation43r.txt" \
	--pathout "cleaned_bga2013.csv" \
	--firstpage 506 \
	--lastpage 550 \
	--bga_string 'Behav Genet (2013) 43:5057550' \
	--twin_registries 'University Twin Registry' 'Osaka University Center for Twin Research' 'Boston University Twin Project' \
		'Center for Twin Research at Osaka University' 'The Norwegian Institute of Public Health Twin Panel' 'Norwegian Institute of Health Twin Panel' \
		'Norwegian Institute of Public Health Twin Panel' 'National Institute on Aging grants' 'National Institute of Health (' \
		'GSA, Abo Akademi University in Finland' 'MTR, University of Murcia in Spain' 'from the National Institute' 'National Institute of Diabetes and Digestive and Kidney Diseases (' \
		'National Institutes of Health [' 'American Institutes for Research investment funds' 'Population Research Center at the University of Texas at Austin' \
		'National Institutes of Health (' 'The Murray Research Archive at Harvard University' 'University of Texas Press' 'National Institute of Aging (' \
		'National Institute on Mental Health MH66206' 'National Institute on Alcohol Abuse and Alcoholism AA023133' 'Brain Behavior Laboratory of the University of Pennsylvania' \
		'University of Southern California (USC) Risk Factors for Antisocial Behavior (RFAB) twin study' 'National Institute of Mental Health (' \
		'National Institute of Child Health and Human Development (' 'University of Washington Twin Registry' 'Twin Study at the QIMR Berghofer Medical Research Institute' \
		'National Institutes of Health AG' 'Florida Department of Education' 'Twin Study at the University of Colorado'


# 2012
python3 ${script} \
	--pathin "2012_Article_BehaviorGeneticsAssociation42n.txt" \
	--pathout "cleaned_bga2012.csv" \
	--firstpage 913 \
	--lastpage 978 \
	--bga_string 'Behav Genet (2012) 42:9124978' \
	--twin_registries 'University Twin Registry' 'Osaka University Center for Twin Research' 'Boston University Twin Project' \
		'Center for Twin Research at Osaka University' 'The Norwegian Institute of Public Health Twin Panel' 'Norwegian Institute of Health Twin Panel' \
		'Norwegian Institute of Public Health Twin Panel' 'National Institute on Aging grants' 'National Institute of Health (' \
		'GSA, Abo Akademi University in Finland' 'MTR, University of Murcia in Spain' 'from the National Institute' 'National Institute of Diabetes and Digestive and Kidney Diseases (' \
		'National Institutes of Health [' 'American Institutes for Research investment funds' 'Population Research Center at the University of Texas at Austin' \
		'National Institutes of Health (' 'The Murray Research Archive at Harvard University' 'University of Texas Press' 'National Institute of Aging (' \
		'National Institute on Mental Health MH66206' 'National Institute on Alcohol Abuse and Alcoholism AA023133' 'Brain Behavior Laboratory of the University of Pennsylvania' \
		'University of Southern California (USC) Risk Factors for Antisocial Behavior (RFAB) twin study' 'National Institute of Mental Health (' \
		'National Institute of Child Health and Human Development (' 'University of Washington Twin Registry' 'Twin Study at the QIMR Berghofer Medical Research Institute' \
		'National Institutes of Health AG' 'Florida Department of Education' 'Twin Study at the University of Colorado' \
		'Sibling Interaction and Behavior Study (SIBS) at the University of Minnesota' 'Twin Study (LTS) at the University of Colorado'


# 2011
python3 ${script} \
	--pathin "2011_Article_BehaviorGeneticsAssociation41s.txt" \
	--pathout "cleaned_bga2011.csv" \
	--firstpage 891 \
	--lastpage 944 \
	--bga_string 'Behav Genet (2012) 42:9124978' \
	--twin_registries 'University Twin Registry' 'Osaka University Center for Twin Research' 'Boston University Twin Project' \
		'Center for Twin Research at Osaka University' 'The Norwegian Institute of Public Health Twin Panel' 'Norwegian Institute of Health Twin Panel' \
		'Norwegian Institute of Public Health Twin Panel' 'National Institute on Aging grants' 'National Institute of Health (' \
		'GSA, Abo Akademi University in Finland' 'MTR, University of Murcia in Spain' 'from the National Institute' 'National Institute of Diabetes and Digestive and Kidney Diseases (' \
		'National Institutes of Health [' 'American Institutes for Research investment funds' 'Population Research Center at the University of Texas at Austin' \
		'National Institutes of Health (' 'The Murray Research Archive at Harvard University' 'University of Texas Press' 'National Institute of Aging (' \
		'National Institute on Mental Health MH66206' 'National Institute on Alcohol Abuse and Alcoholism AA023133' 'Brain Behavior Laboratory of the University of Pennsylvania' \
		'University of Southern California (USC) Risk Factors for Antisocial Behavior (RFAB) twin study' 'National Institute of Mental Health (' \
		'National Institute of Child Health and Human Development (' 'University of Washington Twin Registry' 'Twin Study at the QIMR Berghofer Medical Research Institute' \
		'National Institutes of Health AG' 'Florida Department of Education' 'Twin Study at the University of Colorado' \
		'Sibling Interaction and Behavior Study (SIBS) at the University of Minnesota' 'Twin Study (LTS) at the University of Colorado' \
		'University of Southern California (USC) Twin Project' 'Washington University based Epigenomics Roadmap Visualization Hub'


# 2010
python3 ${script} \
	--pathin "2010_Article_BehaviorGeneticsAssociation40t.txt" \
	--pathout "cleaned_bga2010.csv" \
	--firstpage 785 \
	--lastpage 821 \
	--bga_string 'Behav Genet (2012) 42:9124978' \
	--twin_registries 'University Twin Registry' 'Osaka University Center for Twin Research' 'Boston University Twin Project' \
		'Center for Twin Research at Osaka University' 'The Norwegian Institute of Public Health Twin Panel' 'Norwegian Institute of Health Twin Panel' \
		'Norwegian Institute of Public Health Twin Panel' 'National Institute on Aging grants' 'National Institute of Health (' \
		'GSA, Abo Akademi University in Finland' 'MTR, University of Murcia in Spain' 'from the National Institute' 'National Institute of Diabetes and Digestive and Kidney Diseases (' \
		'National Institutes of Health [' 'American Institutes for Research investment funds' 'Population Research Center at the University of Texas at Austin' \
		'National Institutes of Health (' 'The Murray Research Archive at Harvard University' 'University of Texas Press' 'National Institute of Aging (' \
		'National Institute on Mental Health MH66206' 'National Institute on Alcohol Abuse and Alcoholism AA023133' 'Brain Behavior Laboratory of the University of Pennsylvania' \
		'University of Southern California (USC) Risk Factors for Antisocial Behavior (RFAB) twin study' 'National Institute of Mental Health (' \
		'National Institute of Child Health and Human Development (' 'University of Washington Twin Registry' 'Twin Study at the QIMR Berghofer Medical Research Institute' \
		'National Institutes of Health AG' 'Florida Department of Education' 'Twin Study at the University of Colorado' \
		'Sibling Interaction and Behavior Study (SIBS) at the University of Minnesota' 'Twin Study (LTS) at the University of Colorado' \
		'University of Southern California (USC) Twin Project' 'Washington University based Epigenomics Roadmap Visualization Hub' \
		'College Drinking Sample' 'The Netherlands Twin Register at the VU University' 'University of Vermont, Research Center for Children, Youth, and Families' \


# 2009
python3 ${script} \
	--pathin "2009_Article_BehaviorGeneticsAssociation39t.txt" \
	--pathout "cleaned_bga2009.csv" \
	--firstpage 633 \
	--lastpage 695 \
	--bga_string 'Behav Genet (2012) 42:9124978' \
	--twin_registries 'University Twin Registry' 'Osaka University Center for Twin Research' 'Boston University Twin Project' \
		'Center for Twin Research at Osaka University' 'The Norwegian Institute of Public Health Twin Panel' 'Norwegian Institute of Health Twin Panel' \
		'Norwegian Institute of Public Health Twin Panel' 'National Institute on Aging grants' 'National Institute of Health (' \
		'GSA, Abo Akademi University in Finland' 'MTR, University of Murcia in Spain' 'from the National Institute' 'National Institute of Diabetes and Digestive and Kidney Diseases (' \
		'National Institutes of Health [' 'American Institutes for Research investment funds' 'Population Research Center at the University of Texas at Austin' \
		'National Institutes of Health (' 'The Murray Research Archive at Harvard University' 'University of Texas Press' 'National Institute of Aging (' \
		'National Institute on Mental Health MH66206' 'National Institute on Alcohol Abuse and Alcoholism AA023133' 'Brain Behavior Laboratory of the University of Pennsylvania' \
		'University of Southern California (USC) Risk Factors for Antisocial Behavior (RFAB) twin study' 'National Institute of Mental Health (' \
		'National Institute of Child Health and Human Development (' 'University of Washington Twin Registry' 'Twin Study at the QIMR Berghofer Medical Research Institute' \
		'National Institutes of Health AG' 'Florida Department of Education' 'Twin Study at the University of Colorado' \
		'Sibling Interaction and Behavior Study (SIBS) at the University of Minnesota' 'Twin Study (LTS) at the University of Colorado' \
		'University of Southern California (USC) Twin Project' 'Washington University based Epigenomics Roadmap Visualization Hub' \
		'College Drinking Sample' 'The Netherlands Twin Register at the VU University' 'University of Vermont, Research Center for Children, Youth, and Families' \
		'Netherlands Twin Register at the VU University' 'Genetics of Emotional Ontogeny (GEO) Project at the University of Wisconsin' \
		'Wisconsin Twin Project (WTP) at the University of Wisconsin' 'University of Southern California Twin Study' \
		'Southern California Twin Register at the University of Southern California' \
		'Center for Antisocial Drug Dependence at the University of Colorado'  ''
